@@ -169,6 +169,7 @@
 ( "ejs"                     , "file_type_ejs"                     ) ,
 ( "ejs.t"                   , "file_type_hygen"                   ) ,
 ( "elc"                     , "file_type_emacs"                   ) ,
+( "elm"                     , "file_type_elm"                     ) ,
 ( "el"                      , "file_type_emacs"                   ) ,
 ( "elm-package.json"        , "file_type_elm2"                    ) ,
 ( "emakefile"               , "file_type_erlang2"                 ) ,
@@ -207,6 +208,7 @@
 ( "fods"                    , "file_type_excel2"                  ) ,
 ( "format.ps1xml"           , "file_type_powershell_format"       ) ,
 ( "fossaignore"             , "file_type_fossa"                   ) ,
+( "fs"                      , "file_type_fsharp"                  ) ,
 ( "fsproj"                  , "file_type_fsproj"                  ) ,
 ( "fuse.js"                 , "file_type_fusebox"                 ) ,
 ( "gateway.js"              , "file_type_nest_gateway_js"         ) ,
@@ -239,6 +241,7 @@
 ( "hgignore"                , "file_type_mercurial"               ) ,
 ( "hl"                      , "file_type_binary"                  ) ,
 ( "hpp"                     , "file_type_cppheader"               ) ,
+( "hs"                      , "file_type_haskell"                 ) ,
 ( "htmlhintrc"              , "file_type_htmlhint"                ) ,
 ( "husky.config.js"         , "file_type_husky"                   ) ,
 ( "huskyrc"                 , "file_type_husky"                   ) ,
@@ -269,7 +272,9 @@
 ( "jade-lintrc"             , "file_type_pug"                     ) ,
 ( "jakefile"                , "file_type_jake"                    ) ,
 ( "jakefile.js"             , "file_type_jake"                    ) ,
+( "jar"                     , "file_type_jar"                     ) ,
 ( "jasmine.json"            , "file_type_jasmine"                 ) ,
+( "java"                    , "file_type_java"                    ) ,
 ( "jbuilder"                , "file_type_jbuilder"                ) ,
 ( "jest.config.json"        , "file_type_jest"                    ) ,
 ( "jest.json"               , "file_type_jest"                    ) ,
@@ -295,6 +300,7 @@
 ( "jss"                     , "file_type_jss"                     ) ,
 ( "js.snap"                 , "file_type_jest_snapshot"           ) ,
 ( "jsx.snap"                , "file_type_jest_snapshot"           ) ,
+( "kdl"                     , "file_type_config"                  ) ,
 ( "key"                     , "file_type_key"                     ) ,
 ( "kitchen.yml"             , "file_type_kitchenci"               ) ,
 ( "kiteignore"              , "file_type_kite"                    ) ,
@@ -304,6 +310,7 @@
 ( "layout.html"             , "file_type_layout"                  ) ,
 ( "ldb"                     , "file_type_access2"                 ) ,
 ( "lerna.json"              , "file_type_lerna"                   ) ,
+( "lhs"                     , "file_type_haskell"                 ) ,
 ( "lib"                     , "file_type_binary"                  ) ,
 ( "licence"                 , "file_type_license"                 ) ,
 ( "license"                 , "file_type_license"                 ) ,
@@ -501,17 +508,18 @@
 ( "pre-commit-config.yaml"  , "file_type_precommit"               ) ,
 ( "prettierignore"          , "file_type_prettier"                ) ,
 ( "prettierrc"              , "file_type_prettier"                ) ,
-( "procfile"                , "file_type_procfile"                ) ,
+( "prisma"                  , "file_type_prisma"                  ) ,
 ( "pro"                     , "file_type_prolog"                  ) ,
-( "psd1"                    , "file_type_powershell_psd2"         ) ,
+( "procfile"                , "file_type_procfile"                ) ,
 ( "psd"                     , "file_type_photoshop2"              ) ,
+( "psd1"                    , "file_type_powershell_psd2"         ) ,
 ( "psm1"                    , "file_type_powershell_psm2"         ) ,
 ( "psmdcp"                  , "file_type_nuget"                   ) ,
 ( "pst"                     , "file_type_outlook"                 ) ,
+( "pu"                      , "file_type_plantuml"                ) ,
 ( "pub"                     , "file_type_publisher"               ) ,
 ( "pubspec.lock"            , "file_type_flutter_package"         ) ,
 ( "pubspec.yaml"            , "file_type_flutter_package"         ) ,
-( "pu"                      , "file_type_plantuml"                ) ,
 ( "pug-lintrc"              , "file_type_pug"                     ) ,
 ( "pug-lintrc.js"           , "file_type_pug"                     ) ,
 ( "pug-lintrc.json"         , "file_type_pug"                     ) ,
@@ -535,6 +543,7 @@
 ( "rake"                    , "file_type_rake"                    ) ,
 ( "rar"                     , "file_type_zip2"                    ) ,
 ( "raw"                     , "file_type_audio"                   ) ,
+( "re"                      , "file_type_reason"                  ) ,
 ( "reg"                     , "file_type_registry"                ) ,
 ( "rego"                    , "file_type_rego"                    ) ,
 ( "rehypeignore"            , "file_type_rehype"                  ) ,
@@ -560,10 +569,11 @@
 ( "rwd"                     , "file_type_matlab"                  ) ,
 ( "sailsrc"                 , "file_type_sails"                   ) ,
 ( "sass"                    , "file_type_sass"                    ) ,
-( "scptd"                   , "file_type_binary"                  ) ,
+( "sbt"                     , "file_type_sbt"                     ) ,
+( "scala"                   , "file_type_scala"                   ) ,
 ( "scpt"                    , "file_type_binary"                  ) ,
+( "scptd"                   , "file_type_binary"                  ) ,
 ( "scssm"                   , "file_type_scss"                    ) ,
-// SEE ./README on how to edit this file
 ( "sentryclirc"             , "file_type_sentry"                  ) ,
 ( "sequelizerc"             , "file_type_sequelize"               ) ,
 ( "serverless.yml"          , "file_type_serverless"              ) ,
@@ -608,6 +618,7 @@
 ( "tcl"                     , "file_type_tcl"                     ) ,
 ( "testcaferc.json"         , "file_type_testcafe"                ) ,
 ( "texi"                    , "file_type_tex"                     ) ,
+( "tf"                      , "file_type_terraform"               ) ,
 ( "tfignore"                , "file_type_tfs"                     ) ,
 ( "tfstate"                 , "file_type_terraform"               ) ,
 ( "tgz"                     , "file_type_zip2"                    ) ,
