@@ -5,7 +5,7 @@ use {
     super::*,
     crate::{
         app::Mode,
-        display::ColsConf,
+        display::{ColsConf, LayoutInstructions},
         errors::{ConfError, ProgramError},
         kitty::TransmissionMedium,
         path::{
@@ -143,6 +143,9 @@ pub struct Conf {
     #[serde(default)]
     pub verbs: Vec<VerbConf>,
 
+    #[serde(alias="layout-instructions")]
+    pub layout_instructions: Option<LayoutInstructions>,
+
     // BEWARE: entries added here won't be usable unless also
     // added in read_file!
 }
@@ -232,6 +235,7 @@ impl Conf {
         overwrite!(self, kitty_graphics_transmission, conf);
         overwrite!(self, lines_after_match_in_preview, conf);
         overwrite!(self, lines_before_match_in_preview, conf);
+        overwrite!(self, layout_instructions, conf);
         self.verbs.append(&mut conf.verbs);
         // the following prefs are "additive": we can add entries from several
         // config files and they still make sense
