@@ -55,6 +55,7 @@ macro_rules! Internals {
 Internals! {
     apply_flags: "apply flags (eg `-sd` to show sizes and dates)" false,
     back: "revert to the previous state (mapped to *esc*)" false,
+    default_layout: "restore default panel sizes" false,
     clear_output: "clear the --verb-output file" false,
     clear_stage: "empty the staging area" false,
     close_panel_cancel: "close the panel, not using the selected path" false,
@@ -87,6 +88,7 @@ Internals! {
     line_up_no_cycle: "move one line up" false,
     mode_command: "enter the command mode" false,
     mode_input: "enter the input mode" false,
+    move_panel_divider: "move a panel divider" false,
     next_dir: "select the next directory" false,
     next_match: "select the next match" false,
     next_same_depth: "select the next file at the same depth" false,
@@ -123,6 +125,7 @@ Internals! {
     select: "select a file by path" true,
     select_first: "select the first item" false,
     select_last: "select the last item" false,
+    set_panel_width: "set the width of a panel" false,
     set_syntax_theme: "set the theme of code preview" false,
     sort_by_count: "sort by count" false,
     sort_by_date: "sort by date" false,
@@ -152,6 +155,7 @@ Internals! {
     toggle_tree: "toggle showing more than one level of the tree" true,
     toggle_trim_root: "toggle removing nodes at first level too" false,
     total_search: "search again but on all children" false,
+    search_again: "either put back last search, or search deeper" false,
     trash: "move file to system trash" true,
     unstage: "remove selection from staging area" true,
     up_tree: "focus the parent of the current root" true,
@@ -169,6 +173,8 @@ impl Internal {
             Internal::line_up => r"line_up (?P<count>\d*)?",
             Internal::line_down_no_cycle => r"line_down_no_cycle (?P<count>\d*)?",
             Internal::line_up_no_cycle => r"line_up_no_cycle (?P<count>\d*)?",
+            Internal::move_panel_divider => r"move_panel_divider (?P<idx>\d+) (?P-?<dx>\d+)",
+            Internal::set_panel_width => r"set_panel_width (?P<idx>\d+) (?P<width>\d+)",
             Internal::set_syntax_theme => r"set_syntax_theme {theme:theme}",
             Internal::write_output => r"write_output (?P<line>.*)",
             _ => self.name(),
@@ -182,6 +188,8 @@ impl Internal {
             Internal::line_up => r"line_up {count}",
             Internal::line_down_no_cycle => r"line_down_no_cycle {count}",
             Internal::line_up_no_cycle => r"line_up_no_cycle {count}",
+            Internal::move_panel_divider => r"move_panel_divider {idx} {dx}",
+            Internal::set_panel_width => r"set_panel_width {idx} {width}",
             Internal::write_output => r"write_output {line}",
             _ => self.name(),
         }
